{% for tweet in tweets %}
    <li>
        <blockquote class="twitter-tweet">
            <div class="tweet-basic">
                <div class="tweet-left">
                    <img src="{{ tweet.user.profile_image_url }}"/>
                </div>
                <div class="tweet-right">
                    {{ tweet.user.screen_name }}
                    <p>{{ tweet | render_tweet }}</p>
                </div>
            </div>
            <div class="tweet-entities">
                <div class="media">
                    {% for media in tweet.entities.media %}
                        {{ media|render_image }}
                    {% endfor %}
                </div>
            </div>
        </blockquote>
    </li>
{% endfor %}
