.vertical-offset {
  margin-top: 200px;
}

li {
    list-style: none;
}

ul {
    margin-top: 20px;
}

.tweet-left {
    float: left;
    margin-right: 10px;
}

.tweet-right {
    margin-left: 60px;
}

.tweet-basic {
    min-height: 50px;
    margin-bottom: 10px;
}

blockquote.twitter-tweet {
  display: inline-block;
  font-family: "Helvetica Neue", Roboto, "Segoe UI", Calibri, sans-serif;
  font-size: 12px;
    font-weight: bold;
  line-height: 16px;
  margin: 10px 5px;
  padding: 0 16px 16px 16px;
  max-width: 468px;
}

blockquote.twitter-tweet p {
  font-size: 14px;
  font-weight: normal;
  line-height: 20px;
}

blockquote.twitter-tweet a {
  color: inherit;
  font-weight: normal;
  text-decoration: none;
  outline: 0 none;
}

blockquote.twitter-tweet a:hover,
blockquote.twitter-tweet a:focus {
  text-decoration: underline;
}